@@ -29,25 +29,24 @@ describe 'ceilometer::agent::notification' do
   let :params do
     { :manage_service     => true,
       :enabled            => true,
-      :ack_on_event_error => true,
-      :store_events       => false }
+      :ack_on_event_error => true }
   end
 
   shared_examples_for 'ceilometer-agent-notification' do
 
+    it { is_expected.to contain_class('ceilometer::deps') }
     it { is_expected.to contain_class('ceilometer::params') }
 
     it 'installs ceilometer agent notification package' do
       is_expected.to contain_package(platform_params[:agent_notification_package_name]).with(
         :ensure => 'present',
-        :tag    => 'openstack'
+        :tag    => ['openstack', 'ceilometer-package'],
       )
     end
 
     it 'configures notifications parameters in ceilometer.conf' do
       is_expected.to contain_ceilometer_config('notification/workers').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ceilometer_config('notification/ack_on_event_error').with_value( params[:ack_on_event_error] )
-      is_expected.to contain_ceilometer_config('notification/store_events').with_value( params[:store_events] )
       is_expected.to contain_ceilometer_config('notification/disable_non_metric_meters').with_value('<SERVICE DEFAULT>')
     end
 
@@ -108,7 +107,7 @@ describe 'ceilometer::agent::notification' do
       it 'configures two messaging urls' do
         is_expected.to contain_ceilometer_config('notification/messaging_urls').with_value(
           ['rabbit://rabbit_user:password@localhost/nova', 'rabbit://rabbit_user:password@localhost/neutron']
-        )
+        ).with_secret(true)
       end
     end
 
@@ -118,7 +117,10 @@ describe 'ceilometer::agent::notification' do
       ) }
 
       it { is_expected.to contain_file('event_pipeline').with(
-        'path' => '/etc/ceilometer/event_pipeline.yaml',
+        'path'  => '/etc/ceilometer/event_pipeline.yaml',
+        'owner' => 'root',
+        'group' => 'ceilometer',
+        'mode'  => '0640',
       ) }
 
       it { 'configures event_pipeline with the default notifier'
@@ -135,7 +137,7 @@ describe 'ceilometer::agent::notification' do
           "      transformers:",
           "      triggers:",
           "      publishers:",
-          "          - notifier://",
+          "          - gnocchi://",
       ])}
     end
 
@@ -170,96 +172,49 @@ describe 'ceilometer::agent::notification' do
       ) }
         it { is_expected.not_to contain_file('event_pipeline') }
     end
+
+    context "with pipeline management enabled" do
+      before { params.merge!(
+        :manage_pipeline => true
+      ) }
+
+      it { is_expected.to contain_file('pipeline').with(
+        'path' => '/etc/ceilometer/pipeline.yaml',
+        'mode'  => '0640',
+        'owner' => 'root',
+        'group' => 'ceilometer',
+      ) }
+    end
+
+    context "with pipeline management disabled" do
+      before { params.merge!(
+        :manage_pipeline => false
+      ) }
+        it { is_expected.not_to contain_file('pipeline') }
+    end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :agent_notification_package_name => 'ceilometer-agent-notification',
+            :agent_notification_service_name => 'ceilometer-agent-notification' }
+        when 'RedHat'
+          { :agent_notification_package_name => 'openstack-ceilometer-notification',
+            :agent_notification_service_name => 'openstack-ceilometer-notification' }
+        end
+      end
+
+      it_behaves_like 'ceilometer-agent-notification'
     end
-
-    let :platform_params do
-      { :agent_notification_package_name => 'ceilometer-agent-notification',
-        :agent_notification_service_name => 'ceilometer-agent-notification' }
-    end
-
-    it_configures 'ceilometer-agent-notification'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :agent_notification_package_name => 'openstack-ceilometer-notification',
-        :agent_notification_service_name => 'openstack-ceilometer-notification' }
-    end
-
-    it_configures 'ceilometer-agent-notification'
-  end
-
-  context 'on RHEL 7' do
-    let :facts do
-      @default_facts.merge({ :osfamily                  => 'RedHat',
-        :operatingsystem           => 'RedHat',
-        :operatingsystemmajrelease => 7
-      })
-    end
-
-    let :platform_params do
-      { :agent_notification_package_name => 'openstack-ceilometer-notification',
-        :agent_notification_service_name => 'openstack-ceilometer-notification' }
-    end
-
-    it_configures 'ceilometer-agent-notification'
-  end
-
-  context 'on CentOS 7' do
-    let :facts do
-      @default_facts.merge({ :osfamily                  => 'RedHat',
-        :operatingsystem           => 'CentOS',
-        :operatingsystemmajrelease => 7
-      })
-    end
-
-    let :platform_params do
-      { :agent_notification_package_name => 'openstack-ceilometer-notification',
-        :agent_notification_service_name => 'openstack-ceilometer-notification' }
-    end
-
-    it_configures 'ceilometer-agent-notification'
-  end
-
-  context 'on Scientific 7' do
-    let :facts do
-      @default_facts.merge({ :osfamily                  => 'RedHat',
-        :operatingsystem           => 'Scientific',
-        :operatingsystemmajrelease => 7
-      })
-    end
-
-    let :platform_params do
-      { :agent_notification_package_name => 'openstack-ceilometer-notification',
-        :agent_notification_service_name => 'openstack-ceilometer-notification' }
-    end
-
-    it_configures 'ceilometer-agent-notification'
-  end
-
-  context 'on Fedora 20' do
-    let :facts do
-      @default_facts.merge({ :osfamily               => 'RedHat',
-        :operatingsystem        => 'Fedora',
-        :operatingsystemrelease => 20
-      })
-    end
-
-    let :platform_params do
-      { :agent_notification_package_name => 'openstack-ceilometer-notification',
-        :agent_notification_service_name => 'openstack-ceilometer-notification' }
-    end
-
-    it_configures 'ceilometer-agent-notification'
   end
 
 end
